<?php
/*
File: inc/posttypes/books.php
Description: Register Books Post Type
Plugin: Imager
Author: Alessio Marzo
*/


// Post Type Registration
add_action( 'init', 'im_imager_register_posttype' );

function im_imager_register_posttype() {

	$labels = array(
		'name'               => __('Imager', IM_PLG_NAME),
		'singular_name'      => __('Size', IM_PLG_NAME),
		'add_new'            => __('Add New', IM_PLG_NAME),
		'add_new_item'       => __('Add New Size', IM_PLG_NAME),
		'edit_item'          => __('Edit Size', IM_PLG_NAME),
		'new_item'           => __('New Size', IM_PLG_NAME),
		'all_items'          => __('All Sizes', IM_PLG_NAME),
		'view_item'          => __('View Size', IM_PLG_NAME),
		'search_items'       => __('Search Sizes', IM_PLG_NAME),
		'not_found'          => __('No sizes found', IM_PLG_NAME),
		'not_found_in_trash' => __('No sizes found in Trash', IM_PLG_NAME),
		'parent_item_colon'  => '',
		'menu_name'          => __('Imager', IM_PLG_NAME)
	  );
	
	  $args = array(
		'labels'             => $labels,
		'public'             => true,
		'publicly_queryable' => false,
		'show_ui'            => true,
		'show_in_menu'       => true,
		'show_in_nav_menus' => false,
		'query_var'          => false,
		'rewrite'            => array( 'slug' => 'imager' ),
		'capability_type'    => 'post',
		'has_archive'        => false,
		'hierarchical'       => false,
		'menu_position'      => 10,
		'supports'           => array( 'title'),
		'menu_icon'          => 'dashicons-format-gallery'
	  );
	
	  register_post_type( 'imager', $args );

}


// ADD CUSTOM COLUMNS

// Register the columns
function im_custom_columns_register( $columns ) {
	$columns['desc'] = __('Description', IM_PLG_NAME);
	$columns['size'] = __('Size', IM_PLG_NAME);
	$columns['crop'] = __('Cropped', IM_PLG_NAME);
	return $columns;
}
add_filter( 'manage_edit-imager_columns', 'im_custom_columns_register' );


// Display the column content
function im_custom_columns_display( $column_name, $post_id ) {
	
	if ( $column_name == 'desc' ) {	
 		echo $desc = get_post_meta($post_id, 'im_meta_desc', true);
	}
	if ( $column_name == 'size' ) {	
 		echo $size = '<b>'.get_post_meta($post_id, 'im_meta_width', true).' x '.get_post_meta($post_id, 'im_meta_height', true).'</b> px';
	}
	if ( $column_name == 'crop' && get_post_meta($post_id, 'im_meta_crop', true) == 1 ) {	
 		echo '<b style="color:#0074A2;">YES</b>';
	}
	if ( $column_name == 'crop' && get_post_meta($post_id, 'im_meta_crop', true) != 1 ) {	
 		echo '<b>NO</b>';
	}
		
}

add_action( 'manage_imager_posts_custom_column', 'im_custom_columns_display', 10, 2 );


// Register the column as sortable
function im_custom_columns_display_sortable( $columns ) {
	$columns['size'] = __('Size', IM_PLG_NAME); 
	return $columns;
}

add_filter( 'manage_edit-imager_sortable_columns', 'im_custom_columns_display_sortable' );

function im_custom_columns_orderby( $vars ) {
	if ( isset( $vars['orderby'] ) && 'class' == $vars['orderby'] ) {
		$vars = array_merge( $vars, array(
			'meta_key' => 'im_meta_width',
			'orderby' => 'meta_value'
		) );
	}
 
	return $vars;
}
add_filter( 'request', 'im_custom_columns_orderby' );



// Post Type custom messages
add_filter( 'post_updated_messages', 'im_imager_custom_messages' );

function im_imager_custom_messages( $messages ) {
	
  global $post, $post_ID;

  $messages['imager'] = array(
    0 => '', // Unused. Messages start at index 1.
    1 => __('Size updated.', IM_PLG_NAME),
    2 => __('Custom field updated.', IM_PLG_NAME),
    3 => __('Custom field deleted.', IM_PLG_NAME),
    4 => __('Size updated.', IM_PLG_NAME),
    /* translators: %s: date and time of the revision */
    5 => isset($_GET['revision']) ? sprintf( __('Size restored to revision from %s', IM_PLG_NAME), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
    6 => __('Size published.', IM_PLG_NAME),
    7 => __('Size saved.', IM_PLG_NAME),
    8 => __('Size submitted.', IM_PLG_NAME),
    9 => __('Size scheduled.', IM_PLG_NAME),
    10 => __('Size draft updated.', IM_PLG_NAME)
  );

  return $messages;
  
}


// Settings page function
function im_imager_options() {
		
	
	// Save Options
	if (isset($_POST['update'])) {
		
		update_option('im_global_filter', $_POST['im_global_filter'] );
		update_option('im_watermark', $_POST['im_watermark'] );
		update_option('im_watermark_pos', $_POST['im_watermark_pos'] );
		update_option('im_watermark_op', $_POST['im_watermark_op'] );
		
	}
	
	// Get Saved Options
	$im_global_filter = get_option('im_global_filter');
	$im_watermark = get_option('im_watermark');
	$im_watermark_pos = get_option('im_watermark_pos');
	$im_watermark_op = get_option('im_watermark_op');
	
	?>
	<div class="wrap">
	
	<h2>Settings</h2>
	<p><?php _e('In this section you can attach features on all images in the site', IM_PLG_NAME); ?></p>
	<br>
    
    <form method="POST" action="<?php echo $_SERVER['REQUEST_URI']; ?>">
    
	<h3 class="title"><?php _e('Global Filter', IM_PLG_NAME); ?></h3>
	
    <select class='im_global_filter' name='im_global_filter' id='im_global_filter'>
		<option value='0' <?php if (empty($im_global_filter)){echo 'checked="checked"';} ?>>None</option>
		<option value='im_greyscale_50' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_greyscale_50'){echo 'selected="selected"';} ?>>Grey Scale (50%)</option>
		<option value='im_greyscale_75' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_greyscale_75'){echo 'selected="selected"';} ?>>Grey Scale (75%)</option>
		<option value='im_greyscale_100' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_greyscale_100'){echo 'selected="selected"';} ?>>Grey Scale (100%)</option>
		<option value='im_blur_light' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_blur_light'){echo 'selected="selected"';} ?>>Blur (light)</option>
		<option value='im_blur_normal' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_blur_normal'){echo 'selected="selected"';} ?>>Blur (normal)</option>
		<option value='im_blur_hard' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_blur_hard'){echo 'selected="selected"';} ?>>Blur (hard)</option>
		<option value='im_sepia_50' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_sepia_50'){echo 'selected="selected"';} ?>>Sepia (50%)</option>
		<option value='im_sepia_75' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_sepia_75'){echo 'selected="selected"';} ?>>Sepia (75%)</option>
		<option value='im_sepia_100' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_sepia_100'){echo 'selected="selected"';} ?>>Sepia (100%)</option>
		<option value='im_desaturate_50' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_desaturate_50'){echo 'selected="selected"';} ?>>Desaturation (50%)</option>
		<option value='im_desaturate_0' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_desaturate_0'){echo 'selected="selected"';} ?>>Desaturation (100%)</option>
		<option value='im_saturate_50' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_saturate_50'){echo 'selected="selected"';} ?>>Saturation (50%)</option>
		<option value='im_saturate_100' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_saturate_100'){echo 'selected="selected"';} ?>>Saturation (100%)</option>
		<option value='im_darkness_50' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_darkness_50'){echo 'selected="selected"';} ?>>Darkness (50%)</option>
		<option value='im_darkness_75' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_darkness_75'){echo 'selected="selected"';} ?>>Darkness (75%)</option>
		<option value='im_brightness_50' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_brightness_50'){echo 'selected="selected"';} ?>>Brightness (50%)</option>
		<option value='im_brightness_100' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_brightness_100'){echo 'selected="selected"';} ?>>Brightness (100%)</option>
		<option value='im_lesscontrast_50' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_lesscontrast_50'){echo 'selected="selected"';} ?>>Less Contrast (50%)</option>
		<option value='im_lesscontrast_75' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_lesscontrast_75'){echo 'selected="selected"';} ?>>Less Contrast (75%)</option>
		<option value='im_morecontrast_50' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_morecontrast_50'){echo 'selected="selected"';} ?>>More Contrast (50%)</option>
		<option value='im_morecontrast_100' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_morecontrast_100'){echo 'selected="selected"';} ?>>More Contrast (100%)</option>
		<option value='im_huerotate_45' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_huerotate_45'){echo 'selected="selected"';} ?>>Hue Rotate (45°)</option>
		<option value='im_huerotate_90' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_huerotate_90'){echo 'selected="selected"';} ?>>Hue Rotate (90°)</option>
		<option value='im_huerotate_135' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_huerotate_135'){echo 'selected="selected"';} ?>>Hue Rotate (135°)</option>
		<option value='im_huerotate_180' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_huerotate_180'){echo 'selected="selected"';} ?>>Hue Rotate (180°)</option>
		<option value='im_huerotate_225' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_huerotate_225'){echo 'selected="selected"';} ?>>Hue Rotate (225°)</option>
		<option value='im_huerotate_270' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_huerotate_270'){echo 'selected="selected"';} ?>>Hue Rotate (270°)</option>
		<option value='im_huerotate_315' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_huerotate_315'){echo 'selected="selected"';} ?>>Hue Rotate (315°)</option>
		<option value='im_opacity_30' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_opacity_30'){echo 'selected="selected"';} ?>>Opacity (30%)</option>
		<option value='im_opacity_60' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_opacity_60'){echo 'selected="selected"';} ?>>Opacity (60%)</option>
		<option value='im_opacity_90' <?php if (!empty($im_global_filter) && $im_global_filter == 'im_opacity_90'){echo 'selected="selected"';} ?>>Opacity (90%)</option>
	</select>
     <br><?php _e('<em>This filter will affect only images without filters, so you will not lose the filters you manually attached on your images</em>', IM_PLG_NAME); ?>
    
    <br><br>
    <h3 class="title"><?php _e('Watermark', IM_PLG_NAME); ?></h3>
    
   
    <?php _e('<b>Logo:</b>', IM_PLG_NAME); ?> <br>
    <input id="im_watermark" type="text" size="36" name="im_watermark" value="<?php echo $im_watermark; ?>" />
    <input id="im_watermark_upload" type="button" class="button-secondary" value="Upload Logo" />
    <br><?php _e('<em>A good watermark would be around 100px width or height</em>', IM_PLG_NAME); ?>
    <br><br>
    <?php _e('<b>Position:</b>', IM_PLG_NAME); ?> <br> 
    <select class='im_watermark_pos' name='im_watermark_pos' id='im_watermark_pos'>
		<option value='bottom-right' <?php if (!empty($im_watermark_pos) && $im_watermark_pos == 'bottom-right'){echo 'selected="selected"';} ?>>Bottom Right</option>
        <option value='bottom-left' <?php if (!empty($im_watermark_pos) && $im_watermark_pos == 'bottom-left'){echo 'selected="selected"';} ?>>Bottom Left</option>
        <option value='top-right' <?php if (!empty($im_watermark_pos) && $im_watermark_pos == 'top-right'){echo 'selected="selected"';} ?>>Top Right</option>
        <option value='top-left' <?php if (!empty($im_watermark_pos) && $im_watermark_pos == 'top-left'){echo 'selected="selected"';} ?>>Top Left</option>
    </select>
    <br><br>
    <?php _e('<b>Opacity:</b>', IM_PLG_NAME); ?> <br> 
    <select class='im_watermark_op' name='im_watermark_op' id='im_watermark_op'>
    	<?php for ($i = 1; $i <= 100; $i++ ) { ?>
		<option value='<?php echo $i; ?>' <?php if (!empty($im_watermark_op) && $im_watermark_op == $i ){echo 'selected="selected"';} ?>><?php echo $i.'%'; ?></option>
        <?php } ?>
    </select>
   
    
    <input type="hidden" name="update" value="update">
	<p class="submit"><input type="submit" value="<?php _e('Save Changes', IM_PLG_NAME);?>" class="button-primary" id="submit" name="submit"></p>
    </form>
	
	</div>
    
<?php }